@@ -73,7 +73,30 @@ class RequestsProKeywords(RequestsLibrary):
         uri = str(selected_api_df['uri'][0])
         logger.info('Step-05: End   - Identify uri')
 
-        logger.info('Step-06: Start - Create the parameter and assign to params')
+        logger.info('Step-06: Start - Update the path parameter in URI')
+        # Identify the path parameters specific columns and create a separate data frame
+        selected_api_flt_pp_df = selected_api_df.filter(regex='_pp$', axis=1)
+
+        # Identify the path parameters specific for the api
+        selected_api_flt_pp_df = selected_api_flt_pp_df.dropna(axis='columns')
+
+        # Path Params value which needs to be passed should be as dictionary
+        if selected_api_flt_pp_df.empty:
+            path_params = None
+        else:
+            path_params_list = selected_api_flt_pp_df.to_dict('records')[0]
+
+            # Remove _pp from the parameter name
+            path_params = {x.replace('_pp', ''): v for x, v in path_params_list.items()}
+
+            # Iterate through each values and update the URL
+            for key, value in path_params.items():
+                uri = uri.replace(str('{') + key + str('}'), value)
+            logger.debug(uri)
+
+        logger.info('Step-06: End   - Update the path parameter in URI')
+
+        logger.info('Step-07: Start - Create the parameter and assign to params')
 
         # Identify the parameters specific columns and create a separate data frame
         selected_api_flt_df = selected_api_df.filter(regex='_d$', axis=1)
@@ -89,9 +112,9 @@ class RequestsProKeywords(RequestsLibrary):
 
             # Remove _d from the parameter name
             params = {x.replace('_d', ''): v for x, v in params_list.items()}
-        logger.info('Step-06: End   - Create the parameter and assign to params')
+        logger.info('Step-07: End   - Create the parameter and assign to params')
 
-        logger.info('Step-07: Start - Extract other additional information required - data, auth, headers, files')
+        logger.info('Step-08: Start - Extract other additional information required - data, auth, headers, files')
 
         # Check if data level json is required (body)
         if pd.isna(selected_api_df.loc[0, 'data']):
@@ -144,9 +167,9 @@ class RequestsProKeywords(RequestsLibrary):
         disable_warnings = 0
         debug = 0
 
-        logger.info('Step-07: End   - Extract other additional information required - data, auth, headers, files')
+        logger.info('Step-08: End   - Extract other additional information required - data, auth, headers, files')
 
-        logger.info('Step-08: Start - Trigger the API, extract the response and status code')
+        logger.info('Step-09: Start - Trigger the API, extract the response and status code')
 
         # Condition to check GET/POST method
         if request_type == 'GET':
@@ -169,7 +192,7 @@ class RequestsProKeywords(RequestsLibrary):
                                                         auth=auth, timeout=timeout, proxies=proxies, verify=verify,
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
-                                                        disable_warnings=disable_warnings)
+                                                        disable_warnings=1)
             # Trigger Get method
             response = super(RequestsLibrary, self).put_request(alias=alias, uri=uri, data=data, json=json_data,
                                                                 params=params, files=files, headers=headers,
@@ -180,7 +203,7 @@ class RequestsProKeywords(RequestsLibrary):
                                                         auth=auth, timeout=timeout, proxies=proxies, verify=verify,
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
-                                                        disable_warnings=disable_warnings)
+                                                        disable_warnings=1)
             # Trigger Get method
             response = super(RequestsLibrary, self).post_request(alias=alias, uri=uri, data=data, json=json_data,
                                                                  params=params, headers=headers, files=files,
@@ -192,7 +215,7 @@ class RequestsProKeywords(RequestsLibrary):
             selected_api_df.loc[0, 'API_Response_Content'] = response_string
         else:
             selected_api_df.loc[0, 'API_Response_Content'] = ''
-        logger.info('Step-08: End   - Trigger the API, extract the response and status code')
+        logger.info('Step-09: End   - Trigger the API, extract the response and status code')
         logger.info('*************************************************************************************************')
 
         return selected_api_df
